==> kendo-dropdowns-vue-wrapper-2022.1.412-dev.412.tgz: package/docs/multiselect/index.md <==
---
title: Overview
page_title: MultiSelect Overview - Components - Kendo UI for Vue
description: "Get an overview of the features the Kendo UI MultiSelect wrapper for Vue delivers and use the component in Vue projects."
slug: overview_multiselect
canonicalLink: "https://www.telerik.com/kendo-vue-ui/components/dropdowns/multiselect/"
position: 1
---

<WrapperBanner link="/kendo-vue-ui/components/dropdowns/multiselect"></WrapperBanner>

# MultiSelect Overview

The MultiSelect provides a predefined list for multiple item selection.

The MultiSelect wrapper for Vue is a client-side wrapper for the [Kendo UI MultiSelect](https://docs.telerik.com/kendo-ui/api/javascript/ui/multiselect) widget.

<div data-component="StartFreeTrialSection"></div>

## Basic Usage

The following example demonstrates the MultiSelect in action.

{% meta height:350 %}
{% embed_file multiselect/basic/main.vue preview %}
{% embed_file multiselect/basic/main.js %}
{% endmeta %}

## Functionality and Features

* [Data binding]({% slug databinding_multiselect %})
* [Filtering]({% slug filtering_multiselect %})
* [Virtualization]({% slug virtualization_multiselect %})
* [Grouping]({% slug grouping_multiselect %})
* [Tag mode]({% slug tag_mode_multiselect %})
* [Templates]({% slug templates_multiselect %})
* [Keyboard Nnvigation]({% slug keyboard_navigation_multiselect %})
* [RTL support]({% slug rtl_support_multiselect %})

## Events

The following example demonstrates basic MultiSelect events. You can subscribe to [all MultiSelect events](https://docs.telerik.com/kendo-ui/api/javascript/ui/multiselect#events) by the handler name.

{% meta height:350 %}
{% embed_file multiselect/events/main.vue preview %}
{% embed_file multiselect/events/main.js %}
{% endmeta %}

## Suggested Links

* [Kendo UI MultiSelect for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/multiselect/overview)
* [API Reference of the MultiSelect Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/multiselect)

==> kendo-dropdowns-vue-wrapper-2022.2.621-dev.722.tgz: package/docs/multiselect/index.md <==
---
title: Overview
page_title: MultiSelect Overview - Components - Kendo UI for Vue
description: "Get an overview of the features the Kendo UI MultiSelect wrapper for Vue delivers and use the component in Vue projects."
slug: overview_multiselect_wrapper
canonicalLink: "https://www.telerik.com/kendo-vue-ui/components/dropdowns/multiselect/"
position: 1
---

<WrapperBanner link="/kendo-vue-ui/components/dropdowns/multiselect"></WrapperBanner>

# MultiSelect Overview

The MultiSelect provides a predefined list for multiple item selection.

The MultiSelect wrapper for Vue is a client-side wrapper for the [Kendo UI MultiSelect](https://docs.telerik.com/kendo-ui/api/javascript/ui/multiselect) widget.

<div data-component="StartFreeTrialSection"></div>

## Basic Usage

The following example demonstrates the MultiSelect in action.

{% meta height:350 %}
{% embed_file multiselect/basic/main.vue preview %}
{% embed_file multiselect/basic/main.js %}
{% endmeta %}

## Functionality and Features

* [Data binding]({% slug databinding_multiselect_wrapper %})
* [Filtering]({% slug filtering_multiselect_wrapper %})
* [Virtualization]({% slug virtualization_multiselect_wrapper %})
* [Grouping]({% slug grouping_multiselect_wrapper %})
* [Tag mode]({% slug tag_mode_multiselect_wrapper %})
* [Templates]({% slug templates_multiselect_wrapper %})
* [Keyboard Nnvigation]({% slug keyboard_navigation_multiselect_wrapper %})
* [RTL support]({% slug rtl_support_multiselect_wrapper %})

## Events

The following example demonstrates basic MultiSelect events. You can subscribe to [all MultiSelect events](https://docs.telerik.com/kendo-ui/api/javascript/ui/multiselect#events) by the handler name.

{% meta height:350 %}
{% embed_file multiselect/events/main.vue preview %}
{% embed_file multiselect/events/main.js %}
{% endmeta %}

## Suggested Links

* [Kendo UI MultiSelect for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/multiselect/overview)
* [API Reference of the MultiSelect Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/multiselect)
